@@ -778,7 +778,7 @@ EditorCompletion::~EditorCompletion()
 
 bool EditorCompletion::eventFilter( TQObject *obj, TQEvent *ev )
 {
-  if ( TQT_BASE_OBJECT(obj) == TQT_BASE_OBJECT(d->completionPopup) || TQT_BASE_OBJECT(obj) == TQT_BASE_OBJECT(d->completionListBox) )
+  if ( obj == d->completionPopup || obj == d->completionListBox )
   {
 
     if ( ev->type() == TQEvent::KeyPress )
